@@ -216,7 +216,7 @@ struct EM_descender
 
 
 	/// Handle a calculated Z for one strand of an occurrence of a W-mer
-    GCC_DIAG_OFF(uninitialized);
+    GCC_DIAG_OFF(GCC_UNINIT_WARNING);
 	template< bool RevComp >
 	inline
 	void
@@ -264,7 +264,7 @@ struct EM_descender
 #endif //MS_DO_DEBUG_CHECKS
 		MS_CHECK_IS_FINITE( LL, "LL" );
 	}
-    GCC_DIAG_ON(uninitialized);
+    GCC_DIAG_ON(GCC_UNINIT_WARNING);
 
 
 	/// Handle a calculated Z for both strands of an occurrence of a W-mer
@@ -336,7 +336,7 @@ struct EM_descender
 
 
 	/** Normalise a window at global position, j. */
-    GCC_DIAG_OFF(uninitialized);
+    GCC_DIAG_OFF(GCC_UNINIT_WARNING);
 	inline
 	bool
 	normalise_window_dense( Z_dense_size_t j, Z_dense_size_t max_o ) {
@@ -395,11 +395,9 @@ struct EM_descender
 			return false;
 		}
 	}
-    GCC_DIAG_ON(uninitialized);
 
 
 	/** Normalise a window at global position, j. */
-    GCC_DIAG_OFF(uninitialized);
 	inline
 	bool
 	normalise_window_sparse( Z_sparse_size_t j, Z_sparse_it j_it, Z_sparse_size_t max_o ) {
@@ -463,7 +461,7 @@ struct EM_descender
 			return false; // we did not normalise
 		} /* normalize */
 	}
-    GCC_DIAG_ON(uninitialized);
+    GCC_DIAG_ON(GCC_UNINIT_WARNING);
 
 
 
