@@ -169,24 +169,26 @@ template<
 struct start_finder
 : boost::noncopyable
 {
-	typedef Spec                                       spec;                   ///< Specifications.
 	STEME_TYPEDEF_SEQAN_TYPES( Spec )
-	typedef data< Spec >                               data_t;                 ///< Data type.
-	typedef model< Spec >                              model_t;                ///< Model type.
-    typedef significance< Spec >                       significance_t;         ///< The significance type.
+	typedef data< Spec >                                data_t;                 ///< Data type.
+	typedef model< Spec >                               model_t;                ///< Model type.
+    typedef significance< Spec >                        significance_t;         ///< The significance type.
 	typedef find_best_w_mers< Storage, Spec >          best_w_mers_finder;     ///< Type of find best W-mers.
 	typedef typename best_w_mers_finder::ptr           best_w_mers_ptr;        ///< Pointer to best W-mers structure.
+    typedef w_mer_evaluation< Spec >                    w_mer_eval_t;
+    typedef typename w_mer_eval_t::vec                 eval_vec;
+    typedef typename w_mer_eval_t::vec_ptr             eval_vec_ptr;
 
 	/** A starting point for EM. */
 	struct start
 	: boost::less_than_comparable< start >
 	, boost::equality_comparable< start >
 	{
-		double                                   score;                ///< The start's score.
-		size_t                                   num_sites;            ///< The number of sites used in the start.
-		std::string                              w_mer;                ///< W-mer that seeds the start.
-		w_mer_evaluation::vec_ptr                best_w_mers;          ///< The best W-mers for the seed used to align the start.
-		typename model_t::ptr                    _model;               ///< The model used to evaluate the start.
+		double                                            score;                ///< The start's score.
+		size_t                                             num_sites;            ///< The number of sites used in the start.
+		std::string                                        w_mer;                ///< W-mer that seeds the start.
+		eval_vec_ptr                                       best_w_mers;          ///< The best W-mers for the seed used to align the start.
+		typename model_t::ptr                             _model;               ///< The model used to evaluate the start.
 
 		/** Default constructor. */
 		start()
@@ -196,7 +198,13 @@ struct start_finder
 		}
 
 		/** Constructor. */
-		start( double score, size_t num_sites, std::string w_mer, w_mer_evaluation::vec_ptr best_w_mers, typename model_t::ptr _model )
+		start(
+		    double score,
+		    size_t num_sites,
+		    std::string w_mer,
+		    eval_vec_ptr best_w_mers,
+		    typename model_t::ptr _model
+		)
 		: score( score )
 		, num_sites( num_sites )
 		, w_mer ( w_mer )
@@ -304,7 +312,7 @@ struct start_finder
 	typedef std::vector< size_t >                                num_sites_vec;         ///< Vector of candidate num_sites.
 	typedef boost::function<
 		void (
-		    w_mer_evaluation::vec_ptr best_w_mers,
+		    eval_vec_ptr best_w_mers,
 			const std::string & start,
 			int num_sites,
 			double score
@@ -454,7 +462,7 @@ struct start_finder
 
 
 
-	w_mer_evaluation::vec_ptr
+	eval_vec_ptr
 	find_best_w_mers_for_model() {
         // find the best W-mers under the newly seeded model
         best_w_mers_ptr best_w_mer_finder = best_w_mers_ptr(
@@ -466,7 +474,7 @@ struct start_finder
 	}
 
 
-    w_mer_evaluation::vec_ptr
+	eval_vec_ptr
     find_best_instances_for_model() {
         using boost::lambda::bind;
 
@@ -474,7 +482,7 @@ struct start_finder
         find_instances< Spec > instance_finder( _data, _model, .2 );
         instance_finder.descend_tree();
         // sort them in decreasing Z order
-        boost::sort( *instance_finder.instances, bind( &w_mer_evaluation::Z, boost::lambda::_1 ) > bind( &w_mer_evaluation::Z, boost::lambda::_2 ) );
+        boost::sort( *instance_finder.instances, bind( &w_mer_eval_t::Z, boost::lambda::_1 ) > bind( &w_mer_eval_t::Z, boost::lambda::_2 ) );
         stats += instance_finder.stats; // update start finder stats with stats
         return instance_finder.instances;
     }
@@ -494,7 +502,7 @@ struct start_finder
      */
     inline
     bool
-    do_instances_overlap( const w_mer_evaluation::vec & instances1, const w_mer_evaluation::vec & instances2 ) {
+    do_instances_overlap( const eval_vec & instances1, const eval_vec & instances2 ) {
         const unsigned overlap = calculate_overlap( instances1.begin(), instances1.end(), W, instances2.begin(), instances2.end(), W );
         const double threshold = .3; // if about a third of the bases overlap we say the instances overlap
         return instances1.size() * W * threshold <= overlap;
@@ -521,7 +529,7 @@ struct start_finder
 			_model.bs.seed( pre, true );
 
 			// find the best W-mers
-			w_mer_evaluation::vec_ptr instances = find_best_w_mers_for_model();
+			eval_vec_ptr instances = find_best_w_mers_for_model();
 			BOOST_ASSERT( are_instances_sorted_by_score( *instances ) );
 
             // if we got enough sites
@@ -546,8 +554,8 @@ struct start_finder
                     // do we have enough in the vector?
                     if( starts.size() < num_to_find ) {
                         // no, so add this start
-                        w_mer_evaluation::vec_ptr start_instances(
-                            new w_mer_evaluation::vec( instances->begin(), instances->begin() + actual_num_sites )
+                        eval_vec_ptr start_instances(
+                            new eval_vec( instances->begin(), instances->begin() + actual_num_sites )
                         );
                         sort_instances_by_position( *start_instances );
                         starts.push_back(
@@ -569,8 +577,8 @@ struct start_finder
                             // Now we need a vector of just the instances for this start
                             // so we can check the overlaps with other starts
                             // the instances need to be sorted by position as well
-                            w_mer_evaluation::vec_ptr start_instances(
-                                new w_mer_evaluation::vec( instances->begin(), instances->begin() + actual_num_sites )
+                            eval_vec_ptr start_instances(
+                                new eval_vec( instances->begin(), instances->begin() + actual_num_sites )
                             );
                             sort_instances_by_position( *start_instances );
 
