@@ -123,8 +123,8 @@ currtime(
 /**
  * A wrapper around Bejerano's pvalue calculations
  */
-struct pval_pvalue_calculator :
-    pvalue_calculator {
+struct pval_pvalue_calculator : pvalue_calculator
+{
     int alg;
 
     int N, K, *C0, *n, *perm, underflow, biggest_N;
@@ -253,7 +253,7 @@ struct pval_pvalue_calculator :
         biggest_N = 0;
     }
 
-    ~pval_pvalue_calculator() {
+    virtual ~pval_pvalue_calculator() {
         delete[] Q0;
         delete[] lgQ0;
         delete[] C0;
