@@ -12,7 +12,7 @@ using namespace steme;
 using namespace steme::python;
 
 
-typedef significance< EXPOSED_STEME_SPEC > significance_t;
+typedef significance< STEME_INDEX_MODULE_SPEC > significance_t;
 
 
 void
