@@ -1,4 +1,4 @@
-#include <seqan.h>
+#include <seqan/index.h>
 
 int
 main( int argc, char * argv [] ) {
