@@ -10,10 +10,11 @@ STEME web application.
 import os
 from flask import Flask
 
+
 #
 # Create and configure our application
 #
-app = Flask(__name__)
+app = Flask(__name__.split('.')[0])
 "The web application."
 
 app.popens = []
